@@ -16,8 +16,9 @@ def test_sample_J():
     pa = 0.8
     delta_l = 4
     delta_m = 4
-    assert np.allclose(np.array([[0.52961546+0.j],
-       [0.52961546+0.j]], dtype="complex128"), sample_J(bm_J, bm_pa, bm_chan, bm_pol, delta_l, delta_m, pa, freq, lmn)) == True
+    test1 = np.array([[0.529615457+0.j],[0.529615457+0.j], [0.+0.j], [1.+0.j]], dtype="complex128")
+    test2 = sample_J(bm_J, bm_pa, bm_chan, bm_pol, delta_l, delta_m, pa, freq, lmn)
+    assert np.allclose(test1, test2, rtol = 1e-8) == True
     
     
 def test_sample_J_analytic_airy():
@@ -26,4 +27,5 @@ def test_sample_J_analytic_airy():
     
 def test_sample_J_analytic_CASA():
     lmn = _directional_cosine((2.1, 3.2))
-    assert np.allclose(np.array([-0.00025785+0.j, 0.+0.j, 0.+0.j, -0.00025785+0.j]), sample_J_analytic("casa_airy", 25, 2, lmn, 1.2e9, 1)) == True
\ No newline at end of file
+    #assert np.allclose(np.array([-0.00025785+0.j, 0.+0.j, 0.+0.j, -0.00025785+0.j]), sample_J_analytic("casa_airy", 25, 2, lmn, 1.2e9, 1)) == True
+    assert np.allclose(np.array([0.0002665+0.j, 0.       +0.j, 0.       +0.j, 0.0002665+0.j]), sample_J_analytic("casa_airy", 25, 2, lmn, 1.2e9, 1)) == True
\ No newline at end of file
